@@ -11,12 +11,12 @@ alias yq='/usr/bin/yq'
 RUN_AS_CONTAINER=${RUN_AS_CONTAINER:-false}
 
 # Profile version used by init-cfg-bundle function
-CMS_PROFILE_VERSION="10.2.1"
-COMMON_PROFILE_VERSION="10.2.1"
-CT_PROFILE_VERSION="10.2.1"
-ES_PROFILE_VERSION="10.2.1"
-DB_PROFILE_VERSION="10.2.1"
-ETCD_PROFILE_VERSION="10.2.1"
+CMS_PROFILE_VERSION="10.3.0"
+COMMON_PROFILE_VERSION="10.3.0"
+CT_PROFILE_VERSION="10.3.0"
+ES_PROFILE_VERSION="10.3.0"
+DB_PROFILE_VERSION="10.3.0"
+ETCD_PROFILE_VERSION="10.3.0"
 
 # Profiles mapping
 declare -A PROFILES
@@ -48,7 +48,8 @@ CMSGEOCONF="$SCRIPTPATH/cmsgeo.var"
 CMSCONF_COMBINE="/tmp/cms.var.combine"
 
 #TERRAFORM_VERSION="0.12.29"
-TERRAFORM_VERSION="0.14.5"
+#TERRAFORM_VERSION="0.14.5"
+TERRAFORM_VERSION="1.5.2"
 TF_DEFAULT_VARIABLES="$SCRIPTPATH/_variables.tf"
 # update APIVersion in the manifest files to align with latest kubernetes kubeapi version
 updateAPIVersion="true"
@@ -100,6 +101,11 @@ ALLOW_CREATE_NODE_LABEL=$(get_parameter_value allow_create_node_label true)
 K8S_CLUSTER_DOMAIN=$(get_parameter_value k8s_cluster_domain "cluster.local")
 DEV_MODE=$(get_parameter_value dev_mode)
 
+# Since USE_SPOT_VM will be used in common function from load_cms_charts,
+# need to init USE_SPOT_VM with false.
+# The values will be later set for Azure deployment based on value passed from cms.var.
+USE_SPOT_VM=false
+
 CMS_TYPE=$(get_parameter_value cms_type)
 CMS_TYPE_LOWER=$(echo "$CMS_TYPE" | awk '{print tolower($0)}')
 
@@ -185,7 +191,7 @@ if [[ $CLOUDPLATFORM == "" ]];then
   CONTENT_NAS_SHARE=$(get_parameter_value content_nas_share)
   BACKUP_NAS_SERVER_IP=$(get_parameter_value backup_nas_server_ip)
   BACKUP_NAS_SHARE=$(get_parameter_value backup_nas_share)
-  USER_MODIFIED_STORAGECLASS=$(get_parameter_value user_modified_storageclass)
+  USER_MODIFIED_STORAGECLASS=$(get_parameter_value user_modified_storageclass false)
   DB_LOCAL_VOLUME_PREFIX=$(get_parameter_value db_local_volume_prefix |sed -e 's/\/$//') 
 fi
 
@@ -194,19 +200,28 @@ if [[ -n "$CLOUDPLATFORM" ]];then
 fi
 
 if [[ $CLOUDPLATFORM == "AZURE" ]];then
+  # No need to create node labels for CMS deployment on AKS,
+  # as the labels are already being set in the node pool level.
+  ALLOW_CREATE_NODE_LABEL=false
+
   #Parameters for Cloud deployment spcific
   #PG_DISK_SIZE=$(get_parameter_value pg_disk_size)
   SC_SKU=$(get_parameter_value storageclass_sku)
 
   CMS_NODES_K8S_VERSION=$(get_parameter_value cms_nodes_k8s_version)
   
+  ## Set value based on cms.var only for Azure deployment secnario.
+  USE_SPOT_VM=$(get_parameter_value use_spot_vm false)
+  
   # Azure specific parameters
   AZURE_SUBID=$(get_parameter_value subscription_id)
   AZURE_TENANTID=$(get_parameter_value tenant_id)
   AZURE_CLIENTID=$(get_parameter_value client_id)
   AZURE_CLIENTSECRET=$(get_parameter_value client_secret)
   AZURE_REGION=$(get_parameter_value azure_region)
-  
+
+  SETUP_PRIVATE_AKS=$(get_parameter_value setup_private_aks "false")
+
   # Azure Container Registry 'ACR_NAME' must conform to the following pattern: '^[a-zA-Z0-9]*$'
   ACR_RESOURCEGROUP="cmsacr-rg-$AZURE_REGION"
   #ACR_NAME="MKCMSACR$AZURE_REGION"
@@ -221,9 +236,12 @@ if [[ $CLOUDPLATFORM == "AZURE" ]];then
   ## Azure Storage Account
   #AZURE_STORAGE_ACCOUNT_NAME=$(echo "$CLUSTER_NAME-storage" | sed -e 's/-//g' | cut -c1-23)
 
+  USE_AZURE_FILE_STORAGE=$(get_parameter_value use_azure_file_storage true)
+  USE_AZURE_BLOB_STORAGE=$(get_parameter_value use_azure_blob_storage false)
+
   # Azure-file Static share folder names 
   #AZUREFILE_SHARES="cms-content cms-content-heavy cms-metadata-manager-content cms-conf cms-plugin backup-restore cmscli-plugin cms-sync-utils cms-service-client cms-workflow-runtime"
-  AZUREFILE_SHARES="cms-content cms-metadata-manager-content cms-conf cms-plugin backup-restore cmscli-plugin cms-sync-utils cms-service-client cms-workflow-runtime"
+  AZUREFILE_SHARES="cms-content cms-metadata-manager-content cms-conf cms-plugin backup-restore cmscli-plugin cms-sync-utils cms-service-client cms-workflow-runtime cms-watchfolder-runtime"
 
   # Database disk size, common for both aks and gke
   PG_DISK_SIZE=$(get_parameter_value pg_disk_size "30")
@@ -302,6 +320,7 @@ start_information_print(){
   echo ""|& tee -a $LOG
   echo "Azure Specific Parameters:"|& tee -a $LOG
   echo "----------------------------------------"|& tee -a $LOG
+  echo "  USE_SPOT_VM=$USE_SPOT_VM"|& tee -a $LOG
   echo "  K8S_SERVER_VERSION=$K8S_SERVER_VERSION"|& tee -a $LOG
   echo "  CMS_NODES_K8S_VERSION=$CMS_NODES_K8S_VERSION"|& tee -a $LOG
     if [[ -z "$IMAGE_REGISTRY" ]];then
@@ -327,6 +346,8 @@ start_information_print(){
   echo "  CLOUD_CLUSTER_INSTANCE_NAME=$CLOUD_CLUSTER_INSTANCE_NAME"|& tee -a $LOG
   #echo "  AZURE_STORAGE_ACCOUNT_NAME=$AZURE_STORAGE_ACCOUNT_NAME"|& tee -a $LOG
   echo "  Azure-Disk-StorageClass_SKU=$SC_SKU"|& tee -a $LOG
+  echo "  USE_AZURE_FILE_STORAGE=$USE_AZURE_FILE_STORAGE"|& tee -a $LOG
+  echo "  USE_AZURE_BLOB_STORAGE=$USE_AZURE_BLOB_STORAGE"|& tee -a $LOG
   fi
   echo "=========================================================" |& tee -i -a $LOG
   echo "" |& tee -i -a $LOG
@@ -424,7 +445,7 @@ elif [ "$1" = "clean" ] ; then
 
 elif [ "$1" = "deploy" ] ; then
   # Only asking for confirmation when deploy with on-prem default matrix file.
-  if [[ $CLOUDPLATFORM == "" ]] && [[ -z "${@:2}" ]];then
+  if [[ $CLOUDPLATFORM == "" ]] && [[ -z "${@:2}" ]] && $ALLOW_CREATE_NODE_LABEL;then
     user_confirm "!! *NOTICE* !! Do you confirm you have the products-matrix file configured as expected?
 Enter 'No' if not. Refer to Installation Guide and ensure you have the products-matrix configured as expected first;
 Enter 'Yes' to continue this deployment scripts."
